#A setup file for the module squareFunc.py

from setuptools import setup

setup(name = "perfect_square",
version = "1.0.0",
description = "Simple printer of perfect squares up to a"+ 
" given number",
author = "Sharon Kwikiriza",
py_modules=['perfect_square'],
)

